@@ -317,14 +317,74 @@ class SourceAnalyzer(ast.NodeVisitor):
         # These names will be skipped on import `*` case.
         if id_ in NAMES_TO_SKIP:
             self._source_stats.names_to_skip.add(id_)
-        # Support `__all__` dunder overriding case.
+        # Support `__all__` dunder overriding cases.
         if id_ == __ALL__:
             if isinstance(node.value, (ast.List, ast.Tuple, ast.Set)):
-                for constant in node.value.elts:
-                    k = "s" if hasattr(constant, "s") else "value"
-                    value = getattr(constant, k, "")
-                    if value and isinstance(value, str):
-                        self._source_stats.name_.add(value)
+                #: Support normal `__all__` dunder overriding:
+                #:
+                #: >>> import x, y, z
+                #: >>>
+                #: >>> __all__ = ["x", "y", "z"]
+                self._add_list_names(node.value.elts)
+            elif isinstance(node.value, ast.BinOp):
+                #: Support `__all__` dunder overriding with
+                #: add (`+`) binary operator (concatenation):
+                #:
+                #: >>> import x, y, z, i, j
+                #: >>>
+                #: >>> __all__ = ["x"] + ["y", "z"] + ["i", "j"]
+                #:
+                #: Issue: https://github.com/hadialqattan/pycln/issues/28
+                self._add_concatenated_list_names(node.value)
+
+    @recursive
+    def visit_AugAssign(self, node: ast.AugAssign):
+        id_ = getattr(node.target, "id", None)
+        # Support `__all__` with `+=` operator case.
+        if id_ == __ALL__:
+            if isinstance(node.value, (ast.List, ast.Tuple, ast.Set)):
+                #: Support `__all__` dunder overriding with
+                #: only `+=` operator:
+                #:
+                #: >>> import x, y, z
+                #: >>>
+                #: >>> __all__ += ["x", "y", "z"]
+                self._add_list_names(node.value.elts)
+            elif isinstance(node.value, ast.BinOp):
+                #: Support `__all__` dunder overriding with
+                #: both `+=` and `+` operators:
+                #:
+                #: >>> import x, y, z
+                #: >>>
+                #: >>> __all__ += ["x", "y"] + ["z"]
+                self._add_concatenated_list_names(node.value)
+
+    @recursive
+    def visit_Expr(self, node: ast.Expr):
+        #: Support `__all__` dunder overriding with
+        #: `append` and `extend` operations:
+        #:
+        #: >>> import x, y, z
+        #: >>>
+        #: >>> __all__ = ["x"]
+        #: >>> __all__.append("y")
+        #: >>> __all__.extend(["z"])
+        #:
+        #: Issue: https://github.com/hadialqattan/pycln/issues/29
+        node_value = node.value
+        if (
+            isinstance(node_value, ast.Call)
+            and isinstance(node_value.func, ast.Attribute)
+            and isinstance(node_value.func.value, ast.Name)
+            and node_value.func.value.id == __ALL__
+        ):
+            func_attr = node_value.func.attr
+            if func_attr == "append":
+                self._add_list_names(node_value.args)
+            elif func_attr == "extend":
+                for arg in node_value.args:
+                    if isinstance(arg, ast.List):
+                        self._add_list_names(arg.elts)
 
     def _visit_string_type_annotation(
         self, node: Union[ast.AnnAssign, ast.arg, FunctionDefT]
@@ -372,6 +432,25 @@ class SourceAnalyzer(ast.NodeVisitor):
                 tree = parse_ast(val, mode="eval")
                 self._add_name_attr(tree)
 
+    def _add_concatenated_list_names(self, node: ast.BinOp) -> None:
+        #: Safely add `["x", "y"] + ["i", "j"]`
+        #: `const/str` names to `self._source_stats.name_`.
+        if isinstance(node.right, (ast.List, ast.Tuple, ast.Set)):
+            self._add_list_names(node.right.elts)
+        if isinstance(node.left, (ast.List, ast.Tuple, ast.Set)):
+            self._add_list_names(node.left.elts)
+        elif isinstance(node.left, ast.BinOp):
+            self._add_concatenated_list_names(node.left)
+
+    def _add_list_names(self, node: List[ast.expr]) -> None:
+        # Safely add list `const/str` names to `self._source_stats.name_`.
+        for item in node:
+            if isinstance(item, (ast.Constant, ast.Str)):
+                key = "s" if hasattr(item, "s") else "value"
+                value = getattr(item, key, "")
+                if value and isinstance(value, str):
+                    self._source_stats.name_.add(value)
+
     def _add_name_attr(self, tree: ast.AST):
         # Add any `ast.Name` or `ast.Attribute`
         # child to `self._source_stats`.
@@ -471,17 +550,78 @@ class ImportablesAnalyzer(ast.NodeVisitor):
 
     @recursive
     def visit_Assign(self, node: ast.Assign):
-        # Support `__all__` dunder overriding case.
         id_ = getattr(node.targets[0], "id", None)
+        # Support `__all__` dunder overriding cases.
         if id_ == __ALL__:
+            self._has_all = True
+            self._importables.clear()
             if isinstance(node.value, (ast.List, ast.Tuple, ast.Set)):
-                self._has_all = True
-                self._importables.clear()
-                for constant in node.value.elts:
-                    k = "s" if hasattr(constant, "s") else "value"
-                    value = getattr(constant, k, "")
-                    if value and isinstance(value, str):
-                        self._importables.add(value)
+                #: Support normal `__all__` dunder overriding:
+                #:
+                #: >>> import x, y, z
+                #: >>>
+                #: >>> __all__ = ["x", "y", "z"]
+                self._add_list_names(node.value.elts)
+            elif isinstance(node.value, ast.BinOp):
+                #: Support `__all__` dunder overriding with
+                #: add (`+`) binary operator (concatenation):
+                #:
+                #: >>> import x, y, z, i, j
+                #: >>>
+                #: >>> __all__ = ["x"] + ["y", "z"] + ["i", "j"]
+                #:
+                #: Issue: https://github.com/hadialqattan/pycln/issues/28
+                self._add_concatenated_list_names(node.value)
+
+    @recursive
+    def visit_AugAssign(self, node: ast.AugAssign):
+        id_ = getattr(node.target, "id", None)
+        # Support `__all__` with `+=` operator case.
+        if id_ == __ALL__:
+            self._has_all = True
+            if isinstance(node.value, (ast.List, ast.Tuple, ast.Set)):
+                #: Support `__all__` dunder overriding with
+                #: only `+=` operator:
+                #:
+                #: >>> import x, y, z
+                #: >>>
+                #: >>> __all__ += ["x", "y", "z"]
+                self._add_list_names(node.value.elts)
+            elif isinstance(node.value, ast.BinOp):
+                #: Support `__all__` dunder overriding with
+                #: both `+=` and `+` operators:
+                #:
+                #: >>> import x, y, z
+                #: >>>
+                #: >>> __all__ += ["x", "y"] + ["z"]
+                self._add_concatenated_list_names(node.value)
+
+    @recursive
+    def visit_Expr(self, node: ast.Expr):
+        #: Support `__all__` dunder overriding with
+        #: `append` and `extend` operations:
+        #:
+        #: >>> import x, y, z
+        #: >>>
+        #: >>> __all__ = ["x"]
+        #: >>> __all__.append("y")
+        #: >>> __all__.extend(["z"])
+        #:
+        #: Issue: https://github.com/hadialqattan/pycln/issues/29
+        node_value = node.value
+        if (
+            isinstance(node_value, ast.Call)
+            and isinstance(node_value.func, ast.Attribute)
+            and isinstance(node_value.func.value, ast.Name)
+            and node_value.func.value.id == __ALL__
+        ):
+            func_attr = node_value.func.attr
+            if func_attr == "append":
+                self._add_list_names(node_value.args)
+            elif func_attr == "extend":
+                for arg in node_value.args:
+                    if isinstance(arg, ast.List):
+                        self._add_list_names(arg.elts)
 
     @recursive
     def visit_Import(self, node: ast.Import):
@@ -528,6 +668,25 @@ class ImportablesAnalyzer(ast.NodeVisitor):
             if node not in self._not_importables:
                 self._importables.add(node.id)
 
+    def _add_concatenated_list_names(self, node: ast.BinOp) -> None:
+        #: Safely add `["x", "y"] + ["i", "j"]`
+        #: `const/str` names to `self._importables`.
+        if isinstance(node.right, (ast.List, ast.Tuple, ast.Set)):
+            self._add_list_names(node.right.elts)
+        if isinstance(node.left, (ast.List, ast.Tuple, ast.Set)):
+            self._add_list_names(node.left.elts)
+        elif isinstance(node.left, ast.BinOp):
+            self._add_concatenated_list_names(node.left)
+
+    def _add_list_names(self, node: List[ast.expr]) -> None:
+        # Safely add list `const/str` names to `self._importables`.
+        for item in node:
+            if isinstance(item, (ast.Constant, ast.Str)):
+                key = "s" if hasattr(item, "s") else "value"
+                value = getattr(item, key, "")
+                if value and isinstance(value, str):
+                    self._importables.add(value)
+
     def _compute_not_importables(self, node: Union[FunctionDefT, ast.ClassDef]):
         # Compute class/function not-importables.
         for node_ in ast.iter_child_nodes(node):
@@ -551,7 +710,7 @@ class ImportablesAnalyzer(ast.NodeVisitor):
         """Called if no explicit visitor function exists for a node
         (override)."""
         # Continue visiting if only if `__all__` has not overridden.
-        if not self._has_all:
+        if (not self._has_all) or isinstance(node, ast.AugAssign):
             for _, value in ast.iter_fields(node):
                 if isinstance(value, list):
                     for item in value:
